#!/usr/bin/env python3

# The code in this file is released under the Creative Commons CC0 license,
# i.e., for unrestricted use and without any warranty,
# see the file license_CC0.txt or https://creativecommons.org/publicdomain/zero/1.0/

import numpy as np
import pandas as pd

np.seterr(invalid='ignore', divide='ignore')  # disable numpy warnings about floating-point division 0.0/0.0 it considers invalid


def naiveMaximum(value_a, value_b):
    if value_a > value_b:
        return value_a
    else:
        return value_b


def naiveMaximumSearch(values):
    maximum_so_far = -np.inf  # initialize so that negative infinity is obtained as maximum of empty lists
    for v in values:
        maximum_so_far = naiveMaximum(maximum_so_far, v)
    return maximum_so_far


def loadExampleData():
    df = pd.read_csv('nanExampleData.csv')
    return(np.array(df['x']), np.array(df['y']))


def printDataAndResults(data_series_x, data_series_y, data_series_fraction):
    def formatArrayOfNumbers(data):
        # print one decimal place
        return '[' + ', '.join(['%3.1f'%(i) for i in data]) + ']'

    # print data
    print("Data x:   " + formatArrayOfNumbers(data_series_x))
    print("Data y:   " + formatArrayOfNumbers(data_series_y))
    print("Data x/y: " + formatArrayOfNumbers(data_series_fraction))
    # print summarizing values
    print("Sorted:   " + str(sorted(data_series_fraction)))
    print("Maximum:  " + str(naiveMaximumSearch(data_series_fraction)))
    print("Mean:     " + str(np.mean(data_series_fraction)))


if __name__ == '__main__':
    data_series_x, data_series_y = loadExampleData()
    data_series_fraction = data_series_x / data_series_y
    printDataAndResults(data_series_x, data_series_y, data_series_fraction)
